@@ -16,4 +16,11 @@ pub struct Arguments {
         help = "Ignore every file that matches any of these provided regexes. For example, to all XML and CSV files  `--ignore-file-regex '[.]xml$' '[.]csv$'`."
     )]
     pub ignore_file_regex: Vec<String>,
+
+    #[structopt(
+        long,
+        help = "The minimum number of successive lines that must match to be considered a duplicate.",
+        default_value = "3"
+    )]
+    pub minimum_successive_lines: usize,
 }
