@@ -20,7 +20,7 @@ macro_rules! assert_duplicates_base {
             $raw_files,
         );
         let hashed_files = crate::model::hashed_file::to_hashed_files(&indexed_files);
-        let duplicates = crate::duplicate_detection::get_all_duplicates(hashed_files);
+        let duplicates = crate::duplicate_detection::get_all_duplicates(3, hashed_files);
 
         // Then
         insta::assert_json_snapshot!($snapshot_name, duplicates);
