@@ -25,6 +25,9 @@ fn main() {
         raw_files,
     );
     let hashed_files = crate::model::hashed_file::to_hashed_files(&indexed_files);
-    let duplicates = crate::duplicate_detection::get_all_duplicates(hashed_files);
+    let duplicates = crate::duplicate_detection::get_all_duplicates(
+        arguments.minimum_successive_lines,
+        hashed_files,
+    );
     crate::reporter::pretty_print_duplicates(indexed_files, duplicates);
 }
