@@ -1,17 +1,13 @@
-use crate::model::*;
+use crate::model::duplicate::Duplicates;
+use crate::model::indexed_file::IndexedFiles;
 
 use console::Style;
 
-pub fn pretty_print_duplicates(
-    filename_to_line_number_to_line: FilenameToLineNumberToLine,
-    duplicates: Duplicates,
-) {
+pub fn pretty_print_duplicates(indexed_files: IndexedFiles, duplicates: Duplicates) {
     let red = Style::new().red().bold();
 
     for duplicate in duplicates {
-        let line_number_to_line = filename_to_line_number_to_line
-            .get(&duplicate.file_1)
-            .unwrap();
+        let indexed_file = indexed_files.get(&duplicate.file_1).unwrap();
 
         println!(
             "{}: {} {}: {}-{}",
@@ -35,7 +31,7 @@ pub fn pretty_print_duplicates(
             println!(
                 "{} - {:?}",
                 line_number,
-                line_number_to_line.get(&line_number).unwrap()
+                indexed_file.line_number_to_line.get(&line_number).unwrap()
             );
         }
 
